@@ -13,8 +13,9 @@ static char SccsId[] = "%W%  %G%";
  *		express or implied warranty.
  * Origin:      Doug Tody, NOAO (written for IRAF's Imtool)
  * Modified:	{0} Michael VanHilst	initial version		1 July 1989
- *		{1} Jay Travisano (STScI)    VMS changes        10 Nov 1989
- *              {2} MVH BSDonly strings.h compatability           19 Feb 1990
+ *		{1} Jay Travisano (STScI)    VMS changes	10 Nov 1989
+ *              {2} MVH BSDonly strings.h compatability		19 Feb 1990
+ *              {3} Change R_DISPOSE printer from lw to lp	 1 May 1995
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -55,7 +56,7 @@ screen_dump ()
 }
 #else
 
-#define	R_DISPOSE "lpr -Plw -r %s"	/* printer dispose command	*/
+#define	R_DISPOSE "lpr -Plp -r %s"	/* printer dispose command	*/
 #define P_DISPOSE "lpr -P%s -r %s"	/* dispose to user's printer	*/
 #define	SEGSIZE		16		/* output segment size (bytes)	*/
 #define	SEGBITS		(SEGSIZE*8)
@@ -584,10 +585,13 @@ static char *make_label()
   char username[32];
 #ifndef VMS
   struct passwd *pw;
-  long time();		/* should be in time.h, but only VMS does it */
 #else
   char *getenv();
 #endif
+
+#ifdef SUN
+  long time();		/* should be in time.h, but not in SunOS */
+#endif
   long clock;
   int gethostname();
 
