@@ -7,7 +7,7 @@ static char SccsId[] = "%W%  %G%";
  * Subroutine:	key_response()			returns: void
  * Subroutine:	set_iraf_key_trigger()		returns: void
  * Xlib calls:	XWarpPointer(), XSync()
- * Copyright:	1989 Smithsonian Astrophysical Observatory
+ * Copyright:	1989,1991,1994,1995 Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
@@ -16,6 +16,10 @@ static char SccsId[] = "%W%  %G%";
  * Modified:	{0} Michael VanHilst	initial version		29 June 1989
  *		{1} MVH display window key to trigger IRAF write 16 Aug 1989
  *		{2} MVH support for text cursor			  1 Jun 1991 
+ *		{3} Doug Mink support for centroid		 27 Oct 1994 
+ *		{4} Doug Mink add help                           21 Jun 1995
+ *		{5} Doug Mink reword wcs calls                    6 Jul 1995
+ *		{6} Doug Mink add coordinate conversion          17 Aug 1995
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -82,6 +86,10 @@ void key_response()
   XComposeStatus compose;
   int char_cnt;
   int x, y;
+  char vstring[16];
+  char string[16];
+  int ix,iy,lstr;
+  double xcent,ycent;
   static int bufsize = MAX_MAPPED_STRING_LENGTH;
   char buffer[MAX_MAPPED_STRING_LENGTH];
 #ifdef IMTOOL
@@ -90,6 +98,11 @@ void key_response()
   void magnify_pan(), magnify_disp(), say_goodbye(), disp_panbox();
   void disp_dispbox(), raise_windows(), get_new_cmd(), print_table();
   void ascii_region(), textcursor_keyentry();
+  void print_center(), print_cursor(), wcscom();
+  void get_cursor_pos();
+  int iswcs();
+  double xbuf, ybuf, xfile, yfile;
+  char sysout0[16];
 
   /*  Decode the key event to ascii  */
   char_cnt = XLookupString(&control.event.xkey, buffer, bufsize,
@@ -184,13 +197,13 @@ void key_response()
       /*  Open a new image file (see CmdNew.c)  */
       get_new_cmd();
       break;
-#ifdef QUITKEY
+/* #ifdef QUITKEY */
     case XK_Q:
     case XK_q:
       /*  q FOR QUIT  */
       say_goodbye(0);
       break;
-#endif
+/* #endif */
     case XK_R:
     case XK_r:
       raise_windows();
@@ -214,8 +227,108 @@ void key_response()
 	ascii_region(&control.event.xkey, keysym);
       }
       break;
+    /* Read next image in a 3-D image */ 
+    case XK_plus:
+      img.nimage = img.nimage + 1;
+      (void)new_image();
+      break;
+    /* Read previous image in a 3-D image */ 
+    case XK_minus:
+      if (img.nimage > 1) img.nimage = img.nimage - 1;
+      (void)new_image();
+      break;
+    /* save current cursor position within image in pixel list file */
+    case XK_P:
+    case XK_p:
+    /* save current cursor position within image in region list file */
+    case XK_1:
+      /* save current cursor position within image in region list file */
+    case XK_2:
+	break;
+
+    case XK_B:
+    case XK_b:
+	if (iswcs (wcs))
+	    print_cursor (&control.event,"FK4");
+	break;
+    case XK_G:
+    case XK_g:
+	if (iswcs (wcs))
+	    print_cursor (&control.event,"GALACTIC");
+	break;
+    case XK_J:
+    case XK_j:
+	if (iswcs (wcs))
+	    print_cursor (&control.event,"FK5");
+	break;
+
+    case XK_C:
+    case XK_c:
+	print_cursor (&control.event,"SAME");
+	break;
+
+    case XK_W:
+    case XK_w:
+	if (iswcs (wcs))
+	    /* Get file coordinates of cursor */
+	    (void)get_cursor_pos (&control.event, &xbuf, &ybuf, &xfile, &yfile);
+	    wcscom (wcs,xfile,yfile);
+	break;
+
+    case XK_X:
+    case XK_x:
+	print_center ();
+	break;
+
+    case XK_question:
+	printf ("SAOimage keyboard commands:\n");
+	printf ("A rAise all SAOimage windows to the top and refresh\n");
+	printf ("B print coordinates of cursor in B1950 (FK4) coordinates\n");
+	printf ("C print Coordinates of cursor (x,y, WCS if present)\n");
+	printf ("D Delete the smallest region enclosing the mouse\n");
+	printf ("E save current cursor as an excluded region\n");
+	printf ("G print coordinates of cursor in Galactic coordinates\n");
+	printf ("J print coordinates of cursor in J2000 (FK5) coordinates\n");
+	printf ("N enter New command-line arguments\n");
+	printf ("Q Quit SAOimage\n");
+	printf ("R Raise all SAOimage windows to the top\n");
+	printf ("S Save current cursor as an included region\n");
+	printf ("T print table of the pixel values around current mouse position\n");
+	printf ("W execute WCS command\n");
+	printf ("X print centroid coordinates of cursor (X,y, WCS if present)\n");
+	printf ("+ get next image from 3-D image file\n");
+	printf ("- get previous image from 3-D image file\n");
+	printf ("arrow keys move the cursor\n");
+	break;
+
     default:
       break;
     }
   }
 }
+
+/*
+ * Subroutine:  new_image
+ * Purpose:     Having the image record set, do all that is needed to load
+ *              a new image from the same file
+ */
+static int new_image ( )
+{
+  int init_image(), init_imagebuf();
+  void set_tdisp(), new_display(), new_panbox(), disp_panbox();
+
+  /* get the image dimensions (need file name, type) */
+  if( init_image() == 0 )
+    return(0);
+  /* resize the image buffer */
+  (void)init_imagebuf();
+  /* set display params and force reassessing and rescaling the image */
+  set_tdisp(&coord);
+  buffer.mm.img_leftX = coord.id.srcX1 + 1;
+  /* read new image data */
+  new_display(1, 1, 1, 1);
+  /* replace the panbox with a new one */
+  new_panbox(1);
+  disp_panbox();
+  return( 1 );
+}
